
.. _paths-evolution:

Path Evolution
==============

This page highlights how `sdss_access`` path definitions have evolved between releases, broken up into public data
releases (DRs) and internal SDSS data releases, e.g. MaNGA Product Launches (MPLs) for the MaNGA survey.

Public Data Releases
--------------------

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr16, dr15

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr15, dr14

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr14, dr13

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr13, dr12

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr12, dr11

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr11, dr10

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr10, dr9

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: dr9, dr8

Internal Data Releases
----------------------

MaNGA Product Launches (MPLs)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl9, mpl8

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl8, mpl7

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl7, mpl6

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl6, mpl5

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl5, mpl4

.. changelog:: sdss_access.path.changelog:compute_changelog
   :prog: changes
   :drs: mpl4, mpl3
